Learn R Programming

BigVAR (version 1.0)

SparsityPlot.BigVAR.results: Sparsity Plot of a BigVAR.results object

Description

Sparsity Plot of a BigVAR.results object

Usage

SparsityPlot.BigVAR.results(object)

Arguments

object
BigVAR.results object

Value

  • NA, side effect is graph

Details

Uses levelplot from the lattice package to plot the magnitude of each coefficient in the last coefficient estimated by cv.BigVAR.

See Also

cv.BigVAR, BigVAR.results

Examples

Run this code
data(Y)
Y <- Y[1:100,]
Model1 <- constructModel(Y,p=4,struct="Basic",gran=c(50,10),verbose=FALSE)
SparsityPlot.BigVAR.results(cv.BigVAR(Model1))

Run the code above in your browser using DataLab