Fit a BigVAR object with a structured penalty (VARX-L or HVAR).
Usage
BigVAR.est(object)
Arguments
object
BigVAR object created from ConstructModel
Value
An array of $k \times kp \times n$ or $k\times kp+ms \times n$ coefficient matrices; one for each of the n values of lambda.
Details
Fits HVAR or VARX-L model on a BigVAR object. Does not perform cross-validation. This method allows the user to construct their own penalty parameter selection procedure.