Rdocumentation
powered by
Learn R Programming
BigVAR (version 1.0)
show.BigVAR: Default show method for an object of class BigVAR
Description
Default show method for an object of class BigVAR
Usage
## S3 method for class 'BigVAR': show(object)
Arguments
object
BigVAR
object created from
ConstructModel
Value
Displays the following information about the BigVAR object:
Prints the first 5 rows of
Y
Penalty Structure
Relaxed Least Squares Indicator
Maximum lag order
VARX Specifications (if applicable)
Start, end of cross validation period
See Also
constructModel